camelot.camelot.view.controls.search.SimpleSearchControl

Package camelot :: Package camelot :: Package view :: Package controls :: Module search :: Class SimpleSearchControl |
[hide private]
[frames] | no frames]

# Class SimpleSearchControl

source code

A control that displays a single text field in which search keywords can be typed

emits a search and a cancel signal if the user starts or cancels the search

Instance Methods | [hide private]
__init__(self) | source code
search(self, search_text) Start searching for search_text | source code
emit_search(self) | source code
emit_cancel(self) | source code